*-----------------------------------------------------------------------
*     SWPACK
*-----------------------------------------------------------------------
*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
*-----------------------------------------------------------------------
      SUBROUTINE SWDOPN

      INTEGER   IMAGE(*)
      REAL      WPX(*), WPY(*)
      LOGICAL   LFCATR, LWDATR, LCLATR, LTNATR, LIMATR, LPTATR
      LOGICAL   LFCMOD
      CHARACTER COBJ*(*), COMM*(*)

      LOGICAL   LWAIT, LWAIT0, LWAIT1, LKEY, LDUMP, LALT,
     +          LCOLOR, LSEP, LPRINT, LFGBG, LOPEN
      CHARACTER CMSG*80, CLRMAP*80, CBTMAP*80, CLPR*80, COUT*80, 
     +          CTTL*80, CMAP*80, DSPATH*80
      LOGICAL   LWND
      CHARACTER CIMGFMT*8
      REAL      RIMGCMP
      CHARACTER CNOPN*26

      SAVE

      DATA      CNOPN / 'WORKSTATION IS NOT OPENED.' /
      DATA      LOPEN / .FALSE. /

*     / OPEN ( AND ACTIVATE ) WORKSTATION /

      CALL SGIGET('IWS', JWS)
      CALL SWIGET('IWS', IWS)

      CMSG='GRPH1 : STARTED / IWS = ##.'
      CALL CHNGI(CMSG,'##',JWS,'(I2)')
      CALL MSGDMP('M','SWDOPN',CMSG)

*     / DEVICE DEPENDENT PARAMETERS /

      IF (IWS.EQ.1 .OR. IWS.EQ.2 .OR. IWS.EQ.4) THEN

        CALL SWIGET('IWIDTH ', IWIDTH)
        CALL SWIGET('IHEIGHT', IHEIGH)
        CALL SWIGET('ICLRMAP', ICLRMP)
        CALL SWLGET('LFGBG  ', LFGBG )
        CALL SWCGET('FNAME  ', COUT  )
        CALL SWCGET('TITLE  ', CTTL  )

        CALL SWCMLL
        CALL SWQFNM('CLRMAP ', CLRMAP)
        CALL GLCGET('DSPATH',  DSPATH)
        IF (CLRMAP.EQ.(DSPATH(1:LENC(DSPATH))//'colormap.x11')) THEN
          CALL SWQCMF(ICLRMP,CMAP)
          CALL SWCSET('CLRMAP ',CMAP)
        END IF

        CALL SWQFNM('CLRMAP ', CLRMAP)
        IF (CLRMAP.EQ.' ') THEN
          CALL MSGDMP('E','SWDOPN','COLORMAP FILE DOES NOT EXIST.')
        END IF

        IF (COUT.EQ.' ' .OR. COUT.EQ.'*') CALL OSGARG(0, COUT)
        IF (COUT.EQ.' ') THEN
          COUT = 'DCL'
          CALL CLOWER(COUT)
        END IF

        IF (CTTL.EQ.' ' .OR. CTTL.EQ.'*') CALL DCLVNM(CTTL)

      END IF

      IF (IWS.EQ.1) THEN

        CALL SWIGET('IPOSX  ', IPOSX )
        CALL SWIGET('IPOSY  ', IPOSY )
        CALL SWLGET('LWAIT  ', LWAIT )
        CALL SWLGET('LWAIT0 ', LWAIT0)
        CALL SWLGET('LWAIT1 ', LWAIT1)
        CALL SWLGET('LKEY   ', LKEY  )
        CALL SWLGET('LALT   ', LALT  )
        CALL SWLGET('LDUMP  ', LDUMP )

        CALL SWQFNM('BITMAP ', CBTMAP)
        IF (CBTMAP.EQ.' ') THEN
          CALL MSGDMP('E','SWDOPN','BITMAP FILE DOES NOT EXIST.')
        END IF

        CALL ZXDOPN(IWIDTH, IHEIGH, IPOSX, IPOSY,
     +       LWAIT, LWAIT0, LWAIT1, LKEY, LALT, LDUMP, LFGBG,
     +       CLRMAP, CBTMAP, COUT, CTTL)

      ELSE IF (IWS.EQ.2) THEN

        CALL SWLGET('LCOLOR ', LCOLOR)
        CALL SWLGET('LSEP   ', LSEP  )
        CALL SWLGET('LPRINT ', LPRINT)
        CALL SWCGET('LPR    ', CLPR  )

        CALL Z1DOPN(IWIDTH, IHEIGH, LCOLOR, LSEP, LPRINT,
     +       CLRMAP, COUT, CTTL, CLPR)

      ELSE IF (IWS.EQ.3) THEN

        CALL SWLGET('LWAIT  ', LWAIT)
        CALL GLIGET('NLNSIZE',NLNSZ0)
        CALL SWIGET('NLNSIZE',NLNSIZ)
        CALL GLISET('NLNSIZE',NLNSIZ)

        CALL ZTDOPN(LWAIT)

      ELSE IF (IWS.EQ.4) THEN

        CALL SWIGET('IPOSX  ', IPOSX )
        CALL SWIGET('IPOSY  ', IPOSY )
        CALL SWLGET('LWAIT  ', LWAIT )
        CALL SWLGET('LWAIT0 ', LWAIT0)
        CALL SWLGET('LWAIT1 ', LWAIT1)
        CALL SWLGET('LALT   ', LALT  )
        CALL SWLGET('LKEY   ', LKEY  )
        CALL SWLGET('LDUMP  ', LDUMP )

        CALL SWQFNM('BITMAP ', CBTMAP)
        IF (CBTMAP.EQ.' ') THEN
          CALL MSGDMP('E','SWDOPN','BITMAP FILE DOES NOT EXIST.')
        END IF

        CALL SWLGET('LWND   ', LWND  )

        CALL SWCGET('CIMGFMT ', CIMGFMT)
        CALL SWRGET('RIMGCMP ', RIMGCMP)

        CALL ZGDOPN(IWIDTH, IHEIGH, IPOSX, IPOSY,
     +       LWAIT, LWAIT0, LWAIT1, LALT, LKEY, LDUMP, LWND, LFGBG,
     +       CIMGFMT, RIMGCMP, CLRMAP, CBTMAP, COUT, CTTL)
      END IF
      LOPEN = .TRUE.

      IF (IWS.NE.3) THEN
      CALL SGCLST(CLRMAP)
      END IF

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWDCLS

*     / ( DEACTIVATE AND ) CLOSE WORKSTATION /

      IF (IWS.EQ.1) CALL ZXDCLS
      IF (IWS.EQ.2) CALL Z1DCLS
      IF (IWS.EQ.3) THEN
        CALL ZTDCLS
        CALL GLISET('NLNSIZE',NLNSZ0)
      END IF
      IF (IWS.EQ.4) CALL ZGDCLS
      CMSG='GRPH1 : TERMINATED.'
      CALL MSGDMP('M','SWDCLS',CMSG)
      LOPEN = .FALSE.

      RETURN
*-----------------------------------------------------------------------
*     PAGE
*-----------------------------------------------------------------------
      ENTRY SWPOPN

*     / OPEN PAGE ( OR SCREEN ) /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWPOPN', CNOPN)
      IF (IWS.EQ.1) CALL ZXPOPN
      IF (IWS.EQ.2) CALL Z1POPN
      IF (IWS.EQ.3) CALL ZTPOPN
      IF (IWS.EQ.4) CALL ZGPOPN

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWPCLS

*     / CLOSE PAGE ( OR SCREEN ) /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWPCLS', CNOPN)
      NPAGE=NPAGE+1
      CMSG='GRPH1 : PAGE = ### COMPLETED.'
      CALL CHNGI(CMSG,'###',NPAGE,'(I3)')
      CALL MSGDMP('M','SWPCLS',CMSG)

      IF (IWS.EQ.1) CALL ZXPCLS
      IF (IWS.EQ.2) CALL Z1PCLS
      IF (IWS.EQ.3) CALL ZTPCLS(LWAIT)
      IF (IWS.EQ.4) CALL ZGPCLS

      RETURN
*-----------------------------------------------------------------------
*     OBJECT
*-----------------------------------------------------------------------
      ENTRY SWOOPN(COBJ, COMM)

*     / OPEN OBJECT /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWOOPN', CNOPN)
      IF (IWS.EQ.1) CALL ZXOOPN(COBJ, COMM)
      IF (IWS.EQ.2) CALL Z1OOPN(COBJ, COMM)
      IF (IWS.EQ.3) CALL ZTOOPN(COBJ, COMM)
      IF (IWS.EQ.4) CALL ZGOOPN(COBJ, COMM)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWOCLS(COBJ)

*     / CLOSE OBJECT /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWOCLS', CNOPN)
      IF (IWS.EQ.1) CALL ZXOCLS(COBJ)
      IF (IWS.EQ.2) CALL Z1OCLS(COBJ)
      IF (IWS.EQ.3) CALL ZTOCLS(COBJ)
      IF (IWS.EQ.4) CALL ZGOCLS(COBJ)

      RETURN


*-----------------------------------------------------------------------
*     FULL COLOR (2000/12/10 TEST)
*-----------------------------------------------------------------------
      ENTRY SWQFCC(LFCATR)

*     / INQUIRE FULL COLOR CAPABILITY /

      IF (IWS.EQ.1) CALL ZXQFCC(LFCATR)
      IF (IWS.EQ.2) LFCATR = .TRUE.
      IF (IWS.EQ.3) LFCATR = .FALSE.
      IF (IWS.EQ.4) LFCATR = .TRUE.

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWSFCM(LFCMOD)

*     / SET FULL COLOR MODE /

       IF (IWS.EQ.1) CALL ZXSFCM(LFCMOD)
       IF (IWS.EQ.2) CALL Z1SFCM(LFCMOD)
*      IF (IWS.EQ.3) CALL ZTSFCM(LFCMOD)
       IF (IWS.EQ.4) CALL ZGSFCM(LFCMOD)

      RETURN
*-----------------------------------------------------------------------
*     LINE
*-----------------------------------------------------------------------

      ENTRY SWSWDI(IWDIDX)

*     / SET LINE WIDTH INDEX /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWSWDI', CNOPN)
      IF (IWS.EQ.1) CALL ZXSWDI(IWDIDX)
      IF (IWS.EQ.2) CALL Z1SWDI(IWDIDX)
      IF (IWS.EQ.3) CALL ZTSWDI(IWDIDX)
      IF (IWS.EQ.4) CALL ZGSWDI(IWDIDX)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWSCLI(ICLIDX,LFCATR)

*     / SET LINE COLOR INDEX /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWSCLI', CNOPN)

      IF (IWS.EQ.1) CALL ZXSCLI(ICLIDX)
      IF (IWS.EQ.2) CALL Z1SCLI(ICLIDX)
      IF (IWS.EQ.3) CALL ZTSCLI(ICLIDX)
      IF (IWS.EQ.4) CALL ZGSCLI(ICLIDX)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWSLCL(ICOLOR)

*     / SET LINE COLOR IN 24BIT RGB /
      CALL SGQCL(ICLIDX,NR,NB,NG)
      CALL UIFPAC(NR,NG,NB,NCOLOR)

      IF (IWS.EQ.1) CALL ZXSLCL(NCOLOR)
      IF (IWS.EQ.2) CALL Z1SLCL(NCOLOR)
*      IF (IWS.EQ.3) CALL ZTSLCL(NCOLOR)
      IF (IWS.EQ.4) CALL ZGSLCL(NCOLOR)

      RETURN
*-----------------------------------------------------------------------
*     OPEN
*-----------------------------------------------------------------------
      ENTRY SWGOPN

*     / OPEN GRAPHIC SEGMENT /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWGOPN', CNOPN)
      IF (IWS.EQ.1) CALL ZXGOPN
      IF (IWS.EQ.2) CALL Z1GOPN
      IF (IWS.EQ.3) CALL ZTGOPN
      IF (IWS.EQ.4) CALL ZGGOPN

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWGMOV(WX,WY)

*     / PEN-UP MOVE /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWGMOV', CNOPN)
      IF (IWS.EQ.1) CALL ZXGMOV(WX,WY)
      IF (IWS.EQ.2) CALL Z1GMOV(WX,WY)
      IF (IWS.EQ.3) CALL ZTGMOV(WX,WY)
      IF (IWS.EQ.4) CALL ZGGMOV(WX,WY)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWGPLT(WX,WY)

*     / PEN-DOWN MOVE /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWGPLT', CNOPN)
      IF (IWS.EQ.1) CALL ZXGPLT(WX,WY)
      IF (IWS.EQ.2) CALL Z1GPLT(WX,WY)
      IF (IWS.EQ.3) CALL ZTGPLT(WX,WY)
      IF (IWS.EQ.4) CALL ZGGPLT(WX,WY)

      RETURN
*-----------------------------------------------------------------------
*     CLOSE
*-----------------------------------------------------------------------
      ENTRY SWGCLS

*     / CLOSE GRAPHIC SEGMENT /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWGCLS', CNOPN)
      IF (IWS.EQ.1) CALL ZXGCLS
      IF (IWS.EQ.2) CALL Z1GCLS
      IF (IWS.EQ.3) CALL ZTGCLS
      IF (IWS.EQ.4) CALL ZGGCLS

      RETURN
*-----------------------------------------------------------------------
*     TONE
*-----------------------------------------------------------------------
      ENTRY SWSTCL(ICOLOR)

*     / SET TONE COLOR IN 24BIT RGB /

      IF (IWS.EQ.1) CALL ZXSTCL(ICOLOR)
      IF (IWS.EQ.2) CALL Z1STCL(ICOLOR)
*      IF (IWS.EQ.3) CALL ZTSTCL(ICOLOR)
      IF (IWS.EQ.4) CALL ZGSTCL(ICOLOR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWGTON(NP,WPX,WPY,ITPAT)

*     / HARD FILL /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWGTON', CNOPN)
      IF (IWS.EQ.1) CALL ZXGTON(NP,WPX,WPY,ITPAT)
      IF (IWS.EQ.2) CALL Z1GTON(NP,WPX,WPY,ITPAT)
      IF (IWS.EQ.3) CALL ZTGTON(NP,WPX,WPY,ITPAT)
      IF (IWS.EQ.4) CALL ZGGTON(NP,WPX,WPY,ITPAT)

      RETURN
*-----------------------------------------------------------------------
*     IMAGE
*-----------------------------------------------------------------------
      ENTRY SWIOPN(IWX,IWY,IMW,IMH,
     +             WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4)

*     / OPEN IMAGE /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWIOPN', CNOPN)
      IF (IWS.EQ.1) CALL ZXIOPN(IWX, IWY, IMW, IMH)
      IF (IWS.EQ.2) THEN
        CALL Z1CLIP(WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4)
        CALL Z1IOPN(IWX, IWY, IMW, IMH)
      ENDIF
      IF (IWS.EQ.3) CALL ZTIOPN(IWX, IWY, IMW, IMH)
      IF (IWS.EQ.4) CALL ZGIOPN(IWX, IWY, IMW, IMH)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWIDAT(IMAGE, NLEN)

*     / IMAGE DATA /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWIDAT', CNOPN)
      IF (IWS.EQ.1) CALL ZXIDAT(IMAGE, NLEN)
      IF (IWS.EQ.2) CALL Z1IDAT(IMAGE, NLEN)
      IF (IWS.EQ.3) CALL ZTIDAT(IMAGE, NLEN)
      IF (IWS.EQ.4) CALL ZGIDAT(IMAGE, NLEN)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWICLR(IMAGE, NLEN)

*     / IMAGE DATA (FULL COLOR) /
      IF (IWS.EQ.1) CALL ZXICLR(IMAGE, NLEN)
      IF (IWS.EQ.2) CALL Z1ICLR(IMAGE, NLEN)
*      IF (IWS.EQ.3) CALL ZTICLR(IMAGE, NLEN)
      IF (IWS.EQ.4) CALL ZGICLR(IMAGE, NLEN)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWICLS

*     / IMAGE CLOSE /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWICLS', CNOPN)
      IF (IWS.EQ.1) CALL ZXICLS
      IF (IWS.EQ.2) CALL Z1ICLS
      IF (IWS.EQ.3) CALL ZTICLS
      IF (IWS.EQ.4) CALL ZGICLS

      RETURN
*-----------------------------------------------------------------------
*     MOUSE
*-----------------------------------------------------------------------
      ENTRY SWQPNT(WX,WY,MB)

*     / INQUIRE POSITION OF POINTER /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWQPNT', CNOPN)
      IF (IWS.EQ.1) CALL ZXQPNT(WX,WY,MB)
      IF (IWS.EQ.2) CALL Z1QPNT(WX,WY,MB)
      IF (IWS.EQ.3) CALL ZTQPNT(WX,WY,MB)
      IF (IWS.EQ.4) CALL ZGQPNT(WX,WY,MB)

      RETURN
*-----------------------------------------------------------------------
*     TRANSFORMATION
*-----------------------------------------------------------------------
      ENTRY SWFINT(WX, WY, IWX, IWY)

*     / REAL TO INT /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWFINT', CNOPN)
      IF (IWS.EQ.1) CALL ZXFINT(WX, WY, IWX, IWY)
      IF (IWS.EQ.2) CALL Z1FINT(WX, WY, IWX, IWY)
      IF (IWS.EQ.3) CALL ZTFINT(WX, WY, IWX, IWY)
      IF (IWS.EQ.4) CALL ZGFINT(WX, WY, IWX, IWY)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWIINT(IWX, IWY, WX, WY)

*     / INT TO REAL /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWIINT', CNOPN)
      IF (IWS.EQ.1) CALL ZXIINT(IWX, IWY, WX, WY)
      IF (IWS.EQ.2) CALL Z1IINT(IWX, IWY, WX, WY)
      IF (IWS.EQ.3) CALL ZTIINT(IWX, IWY, WX, WY)
      IF (IWS.EQ.4) CALL ZGIINT(IWX, IWY, WX, WY)

      RETURN
*-----------------------------------------------------------------------
*     INQUIRY
*-----------------------------------------------------------------------
      ENTRY SWQWDC(LWDATR)

*     / INQUIRE LINE WIDTH CAPABILITY /

      IF (IWS.EQ.1) CALL ZXQWDC(LWDATR)
      IF (IWS.EQ.2) CALL Z1QWDC(LWDATR)
      IF (IWS.EQ.3) CALL ZTQWDC(LWDATR)
      IF (IWS.EQ.4) CALL ZGQWDC(LWDATR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWQCLC(LCLATR)

*     / INQUIRE LINE COLOR CAPABILITY /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWQCLC', CNOPN)
      IF (IWS.EQ.1) CALL ZXQCLC(LCLATR)
      IF (IWS.EQ.2) CALL Z1QCLC(LCLATR)
      IF (IWS.EQ.3) CALL ZTQCLC(LCLATR)
      IF (IWS.EQ.4) CALL ZGQCLC(LCLATR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWQTNC(LTNATR)

*     / INQUIRE HARD FILL CAPABILITY /

      IF (IWS.EQ.1) CALL ZXQTNC(LTNATR)
      IF (IWS.EQ.2) CALL Z1QTNC(LTNATR)
      IF (IWS.EQ.3) CALL ZTQTNC(LTNATR)
      IF (IWS.EQ.4) CALL ZGQTNC(LTNATR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWQIMC(LIMATR)

*     / INQUIRE BIT IMAGE CAPABILITY /

      IF (IWS.EQ.1) CALL ZXQIMC(LIMATR)
      IF (IWS.EQ.2) CALL Z1QIMC(LIMATR)
      IF (IWS.EQ.3) CALL ZTQIMC(LIMATR)
      IF (IWS.EQ.4) CALL ZGQIMC(LIMATR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWQPTC(LPTATR)

*     / INQUIRE MOUSE POINT CAPABILITY /

      IF (IWS.EQ.1) CALL ZXQPTC(LPTATR)
      IF (IWS.EQ.2) CALL Z1QPTC(LPTATR)
      IF (IWS.EQ.3) CALL ZTQPTC(LPTATR)
      IF (IWS.EQ.4) CALL ZGQPTC(LPTATR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)

*     / INQUIRE WORKSTATION RECTANGLE /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWQRCT', CNOPN)
      IF (IWS.EQ.1) CALL ZXQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
      IF (IWS.EQ.2) CALL Z1QRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
      IF (IWS.EQ.3) CALL ZTQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
      IF (IWS.EQ.4) CALL ZGQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWSROT(IWTROT)

*     / SET FRAME ROTATION FLAG /

      IF (.NOT. LOPEN)
     +   CALL MSGDMP('E', 'SWSROT', CNOPN)
      IF (IWS.EQ.1) CALL ZXSROT(IWTROT)
      IF (IWS.EQ.2) CALL Z1SROT(IWTROT)
      IF (IWS.EQ.3) CALL ZTSROT(IWTROT)
      IF (IWS.EQ.4) CALL ZGSROT(IWTROT)

      RETURN

*-----------------------------------------------------------------------
      ENTRY SWCLCH()

*     / CHANGE COLORMAP IMMIDIATELY /

      CALL SWIGET('ICLRMAP', ICLRMP)
      CALL SWQCMF(ICLRMP,CMAP)
      CALL SWCSET('CLRMAP',CMAP)
      CALL SWQFNM('CLRMAP ', CLRMAP)
      IF (CLRMAP.EQ.' ') THEN
        CALL MSGDMP('E','SWDOPN','COLORMAP FILE DOES NOT EXIST.')
      END IF

      IF (IWS.EQ.1) CALL ZXCLINI(CLRMAP,LFGBG)
      IF (IWS.EQ.2) CALL Z1CLINI(CLRMAP)
*      IF (IWS.EQ.3) CALL ZTCLINI(CLRMAP,LFGBG)
      IF (IWS.EQ.4) CALL ZGCLINI(CLRMAP,LFGBG)

      RETURN

      END

